@@ -18,7 +18,8 @@ class Auth:
             'password': password
         }
 
-        self.client.post(url, data=data)
-
+        r = self.client.post(url, data=data)
+        r.raise_for_status()
+        
         if not self.is_login:
             raise Exception('Cannot login.')
